@@ -24,7 +24,7 @@
 #include "davcollection.h"
 #include "davurl.h"
 
-#include <KCoreAddons/KJob>
+#include <KJob>
 
 namespace KDAV
 {
@@ -54,7 +54,7 @@ public:
     /**
      * Starts the job.
      */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     /**
      * Returns the list of fetched DAV collections.
@@ -70,10 +70,8 @@ Q_SIGNALS:
      */
     void collectionDiscovered(int protocol, const QString &collectionUrl, const QString &configuredUrl);
 
-private Q_SLOTS:
-    void davJobFinished(KJob *);
-
 private:
+    void davJobFinished(KJob *);
     DavUrl::List mUrls;
     DavCollection::List mCollections;
     uint mSubJobCount;
